@@ -69,7 +69,7 @@ bool Box_Reports::fill_from_database()
 {
   Bakery::BusyCursor busy_cursor(get_app_window());
 
-  bool result = Box_DB::fill_from_database();
+  bool result = Box_DB_Table::fill_from_database();
 
   //Enable/Disable extra widgets:
   bool developer_mode = (get_userlevel() == AppState::USERLEVEL_DEVELOPER);
@@ -117,8 +117,6 @@ bool Box_Reports::fill_from_database()
 
   //TODO:
 
-  fill_end();
-
   m_AddDel.set_allow_add(developer_mode);
   m_AddDel.set_allow_delete(developer_mode);
 
@@ -135,6 +133,16 @@ void Box_Reports::on_adddel_Add(const Gtk::TreeModel::iterator& row)
     report->set_name(report_name);
     m_AddDel.set_value_key(row, report_name);
 
+    //Set a suitable starting title, if there is none already:
+    Glib::ustring title = m_AddDel.get_value(row, m_colTitle);
+    if(title.empty())
+    {
+      title = Utils::title_from_string(report_name);
+      m_AddDel.set_value(row, m_colTitle, title);
+    }
+
+    report->set_title(title);
+
     get_document()->set_report(m_table_name, report);
   }
 }
