@@ -24,7 +24,7 @@
 #include <gtkmm/dialog.h>
 #include "../utility_widgets/dialog_properties.h"
 #include <glom/libglom/document/document_glom.h>
-#include "../box_db.h"
+#include "../box_withbuttons.h"
 
 namespace Glom
 {
