@@ -24,6 +24,7 @@
 #include "dialog_copy_translation.h"
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
 #include "glom/libglom/utils.h"
+#include "glom/libglom/glade_utils.h"
 
 #include <glibmm/i18n.h>
 #include <string.h> // for memset
@@ -32,7 +33,6 @@
 #include <gettext-po.h>
 #include "config.h" //For HAVE_GETTEXTPO_XERROR
 
-#include <libgnomevfsmm/handle.h>
 #include <sstream>
 
 namespace Glom
@@ -125,7 +125,7 @@ void Window_Translations::enable_buttons()
 
 void Window_Translations::on_button_identify()
 {
-  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_translation_identify_original");
+  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_translation_identify_original");
   if(refXml)
   {
     Dialog_IdentifyOriginal* dialog = 0;
@@ -355,7 +355,7 @@ void Window_Translations::on_button_ok()
 
 void Window_Translations::on_button_copy_translation()
 {
-   Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_translation_copy");
+   Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_translation_copy");
   if(refXml)
   {
     Dialog_CopyTranslation* dialog = 0;
@@ -500,6 +500,7 @@ void Window_Translations::on_button_export()
   
   //Show the file-chooser dialog, to select an output .po file:
   Gtk::FileChooserDialog file_dlg(_("Choose .po File Name"), Gtk::FILE_CHOOSER_ACTION_SAVE);
+  file_dlg.set_do_overwrite_confirmation();
   
   // Only po files
   Gtk::FileFilter filter;
@@ -576,7 +577,7 @@ void Window_Translations::on_button_import()
   if (setjmp(jump) != 0)
     return;
 
-  Gtk::FileChooserDialog file_dlg(_("Choose .po file name"), Gtk::FILE_CHOOSER_ACTION_OPEN);
+  Gtk::FileChooserDialog file_dlg(_("Choose .po File Name"), Gtk::FILE_CHOOSER_ACTION_OPEN);
   
   // Only po files
   Gtk::FileFilter filter;
@@ -585,7 +586,9 @@ void Window_Translations::on_button_import()
   file_dlg.add_filter(filter);
 
   file_dlg.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-  file_dlg.add_button(_("Import"), Gtk::RESPONSE_OK);  
+
+  //Note to translators: "Import" here is an action verb - it's a button. 
+  file_dlg.add_button(_("Import"), Gtk::RESPONSE_OK);
   
   int result = file_dlg.run();
   if (result == Gtk::RESPONSE_OK)
