@@ -20,6 +20,7 @@
 
 #include "datawidget.h"
 #include "entryglom.h"
+#include "checkglom.h"
 #include "labelglom.h"
 #include "comboentryglom.h"
 #include "comboglom.h"
@@ -32,6 +33,7 @@
 #include "dialog_choose_date.h"
 #include "../layout_item_dialogs/dialog_field_layout.h"
 #include <glom/libglom/utils.h>
+#include <glom/libglom/glade_utils.h>
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -53,13 +55,14 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
   const Glib::ustring title = field->get_title_or_name();
   if(glom_type == Field::TYPE_BOOLEAN)
   {
-    Gtk::CheckButton* checkbutton = Gtk::manage( new Gtk::CheckButton( title ) );
+    CheckGlom* checkbutton = Gtk::manage( new CheckGlom( title ) );
     checkbutton->show();
     checkbutton->signal_toggled().connect( sigc::mem_fun(*this, &DataWidget::on_widget_edited)  );
 
     //TODO: entry->signal_user_requested_layout().connect( sigc::mem_fun(*this, &DataWidget::on_child_user_requested_layout );
 
     m_child = checkbutton;
+    pFieldWidget = checkbutton;
 
     m_label.set_text( Glib::ustring() ); //It is not used.
   }
@@ -80,9 +83,12 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
     m_label.set_alignment(0);
     m_label.show();
   }
+  // Use hildon widgets for date and time on maemo
   else
   {
-    m_label.set_label(title);
+    //The GNOME HIG says that labels should have ":" at the end:
+    //http://library.gnome.org/devel/hig-book/stable/design-text-labels.html.en
+    m_label.set_label(title + ":");
     m_label.set_alignment(0);
     m_label.show();
 
@@ -150,7 +156,7 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
     }
     else
     {
-      if(field->get_formatting_used().get_text_format_multiline())
+      if((glom_type == Field::TYPE_TEXT) && (field->get_formatting_used().get_text_format_multiline()))
       {
         TextViewGlom* textview = Gtk::manage(new TextViewGlom(glom_type));
         pFieldWidget = textview;
@@ -161,7 +167,8 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
         pFieldWidget = entry;
       }
 
-      pFieldWidget->set_layout_item( get_layout_item(), table_name); //TODO_Performance: We only need this for the numerical format.
+      if(pFieldWidget)
+        pFieldWidget->set_layout_item( get_layout_item(), table_name); //TODO_Performance: We only need this for the numerical format.
     }
   }
 
@@ -169,46 +176,34 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
   {
     pFieldWidget->signal_edited().connect( sigc::mem_fun(*this, &DataWidget::on_widget_edited)  );
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
     pFieldWidget->signal_user_requested_layout().connect( sigc::mem_fun(*this, &DataWidget::on_child_user_requested_layout) );
     pFieldWidget->signal_user_requested_layout_properties().connect( sigc::mem_fun(*this, &DataWidget::on_child_user_requested_layout_properties) );
     pFieldWidget->signal_layout_item_added().connect( sigc::mem_fun(*this, &DataWidget::on_child_layout_item_added) );
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
 
     m_child = dynamic_cast<Gtk::Widget*>(pFieldWidget);
-    const int width = get_suitable_width(field);
-
-    if(glom_type == Field::TYPE_IMAGE) //GtkImage widgets default to no size (invisible) if they are empty.
-      m_child->set_size_request(width, width);
-    else
-    {
-      int height = -1; //auto.
-      if(field->get_formatting_used().get_text_format_multiline())
-      {
-        int example_width = 0;
-        int example_height = 0;
-        Glib::RefPtr<Pango::Layout> refLayout = create_pango_layout("example"); //TODO: Use different text, according to the current locale, or allow the user to choose an example?
-        refLayout->get_pixel_size(example_width, example_height);
-        if(example_height > 0)
-          height = example_height * field->get_formatting_used().get_text_format_multiline_height_lines();
-      }
-
-      m_child->set_size_request(width, height);
-    }
+    set_child_size_by_field(field);
 
     m_child->show_all();
   }
 
   if(m_child)
   {
+    //Use the text formatting:
+    apply_formatting(*m_child, field->get_formatting_used());
+    
     bool child_added = false; //Don't use an extra container unless necessary.
     const bool field_used_in_relationship_to_one = document->get_field_used_in_relationship_to_one(table_name, field->get_name());
 
     Gtk::HBox* hbox_parent = 0; //Only used if there are extra widgets.
+
     const bool with_extra_widgets = field_used_in_relationship_to_one || (glom_type == Field::TYPE_DATE);
     if(with_extra_widgets)
     {
       hbox_parent = Gtk::manage( new Gtk::HBox() ); //We put the child (and any extra stuff) in this:
-      hbox_parent->set_spacing(6);
+      hbox_parent->set_spacing(Utils::DEFAULT_SPACING_SMALL);
 
       hbox_parent->pack_start(*m_child);
       add(*hbox_parent);
@@ -220,6 +215,7 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
     {
       //Let the user choose a date from a calendar dialog:
       Gtk::Button* button_date = Gtk::manage(new Gtk::Button(_("..."))); //TODO: A better label/icon for "Choose Date". 
+      button_date->set_tooltip_text(_("Choose a date from an on-screen calendar.")); 
       button_date->show();
       hbox_parent->pack_start(*button_date);
       button_date->signal_clicked().connect(sigc::mem_fun(*this, &DataWidget::on_button_choose_date));
@@ -229,10 +225,12 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
     {
       //Add buttons for related record navigation:
       Gtk::Button* button_go_to_details = Gtk::manage(new Gtk::Button(Gtk::Stock::OPEN));
+      button_go_to_details->set_tooltip_text(_("Open the record identified by this ID, in the other table."));
       hbox_parent->pack_start(*button_go_to_details);
       button_go_to_details->signal_clicked().connect(sigc::mem_fun(*this, &DataWidget::on_button_open_details));
 
       Gtk::Button* button_select = Gtk::manage(new Gtk::Button(Gtk::Stock::FIND));
+      button_select->set_tooltip_text(_("Enter search criteria to identify records in the other table, to choose an ID for this field."));
       hbox_parent->pack_start(*button_select);
       button_select->signal_clicked().connect(sigc::mem_fun(*this, &DataWidget::on_button_select_id));
     }
@@ -241,10 +239,12 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
       add(*m_child);
   }
 
-
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   setup_menu();
+#endif // GLOM_ENABLE_CLIENT_ONLY
 
   set_events(Gdk::BUTTON_PRESS_MASK);
+  signal_style_changed().connect(sigc::mem_fun(*this, &DataWidget::on_self_style_changed));
 }
 
 DataWidget::~DataWidget()
@@ -315,6 +315,30 @@ const Gtk::Label* DataWidget::get_label() const
   return &m_label;
 }
 
+void DataWidget::set_child_size_by_field(const sharedptr<const LayoutItem_Field>& field)
+{
+  const Field::glom_field_type glom_type = field->get_glom_type();
+  const int width = get_suitable_width(field);
+
+  if(glom_type == Field::TYPE_IMAGE) //GtkImage widgets default to no size (invisible) if they are empty.
+    m_child->set_size_request(width, width);
+  else
+  {
+    int height = -1; //auto.
+    if((glom_type == Field::TYPE_TEXT) && (field->get_formatting_used().get_text_format_multiline()))
+    {
+      int example_width = 0;
+      int example_height = 0;
+      Glib::RefPtr<Pango::Layout> refLayout = create_pango_layout("example"); //TODO: Use different text, according to the current locale, or allow the user to choose an example?
+      refLayout->get_pixel_size(example_width, example_height);
+      if(example_height > 0)
+        height = example_height * field->get_formatting_used().get_text_format_multiline_height_lines();
+    }
+
+    m_child->set_size_request(width, height);
+  }
+}
+
 int DataWidget::get_suitable_width(const sharedptr<const LayoutItem_Field>& field_layout)
 {
   int result = 150;
@@ -341,14 +365,24 @@ int DataWidget::get_suitable_width(const sharedptr<const LayoutItem_Field>& fiel
     }
     case(Field::TYPE_NUMERIC):
     {
+#ifdef GLOM_ENABLE_MAEMO
+      //Maemo's screen is not so big, so don't be so generous:
+      example_text = "EUR 9999999";
+#else
       example_text = "EUR 9999999999";
+#endif
       break;
     }
     case(Field::TYPE_TEXT):
     case(Field::TYPE_IMAGE): //Give images the same width as text fields, so they will often line up.
     {
       //if(!field_layout->get_text_format_multiline()) //Use the full width for multi-line text.
+#ifdef GLOM_ENABLE_MAEMO
+        //Maemo's screen is not so big, so don't be so generous:
+        example_text = "AAAAAAAAAAAAAAAA";
+#else
         example_text = "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
+#endif
       break;
     }
     default:
@@ -384,7 +418,7 @@ void DataWidget::set_viewable(bool viewable)
   {
     Gtk::CheckButton* checkbutton = dynamic_cast<Gtk::CheckButton*>(child);
     if(checkbutton)
-      checkbutton->property_inconsistent() = !viewable;
+      checkbutton->set_property("inconsistent", !viewable);
   }
 }
 
@@ -482,6 +516,7 @@ void DataWidget::setup_menu()
 }
 */
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 bool DataWidget::on_button_press_event(GdkEventButton *event)
 {
   //g_warning("DataWidget::on_button_press_event_popup");
@@ -515,6 +550,7 @@ bool DataWidget::on_button_press_event(GdkEventButton *event)
 
   return Gtk::EventBox::on_button_press_event(event);
 }
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
 sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name)
 {
@@ -522,46 +558,65 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& ta
 }
 
 sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field)
+{
+  return offer_field_list (table_name, start_field, get_document(), get_application());
+}
+
+sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field, Document_Glom* document, App_Glom* app)
 {
   sharedptr<LayoutItem_Field> result;
 
+  Glib::RefPtr<Gnome::Glade::Xml> refXml;
+
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_choose_field");
-
-    Dialog_ChooseField* dialog = 0;
-    refXml->get_widget_derived("dialog_choose_field", dialog);
-
-    if(dialog)
-    {
-      dialog->set_document(get_document(), table_name, start_field);
-      dialog->set_transient_for(*get_application());
-      int response = dialog->run();
-      dialog->hide();
-      if(response == Gtk::RESPONSE_OK)
-      {
-        //Get the chosen field:
-        result = dialog->get_field_chosen();
-      }
-
-      delete dialog;
-    }
+    refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_field");
   }
   catch(const Gnome::Glade::XmlError& ex)
   {
     std::cerr << ex.what() << std::endl;
+    return result;
+  }
+#else
+  std::auto_ptr<Gnome::Glade::XmlError> error;
+  refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_field", "", error);
+  if(error.get())
+  {
+    std::cerr << error->what() << std::endl;
+    return result;
+  }
+#endif
+  
+  Dialog_ChooseField* dialog = 0;
+  refXml->get_widget_derived("dialog_choose_field", dialog);
+
+  if(dialog)
+  {
+    dialog->set_document(document, table_name, start_field);
+    dialog->set_transient_for(*app);
+    int response = dialog->run();
+    dialog->hide();
+    if(response == Gtk::RESPONSE_OK)
+    {
+      //Get the chosen field:
+      result = dialog->get_field_chosen();
+    }
+
+    delete dialog;
   }
 
   return result;
 }
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 sharedptr<LayoutItem_Field> DataWidget::offer_field_layout(const sharedptr<const LayoutItem_Field>& start_field)
 {
   sharedptr<LayoutItem_Field> result;
 
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_layout_field_properties");
+    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_layout_field_properties");
 
     Dialog_FieldLayout* dialog = 0;
     refXml->get_widget_derived("dialog_layout_field_properties", dialog);
@@ -590,6 +645,7 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_layout(const sharedptr<const
 
   return result;
 }
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
 /*
 void DataWidget::on_menupopup_add_item(LayoutWidgetBase::enumType item)
@@ -598,6 +654,7 @@ void DataWidget::on_menupopup_add_item(LayoutWidgetBase::enumType item)
 }
 */
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 void DataWidget::on_menupopup_activate_layout()
 {
   //finish_editing();
@@ -641,6 +698,7 @@ void DataWidget::on_child_user_requested_layout()
 {
   on_menupopup_activate_layout();
 }
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
 App_Glom* DataWidget::get_application()
 {
@@ -650,10 +708,13 @@ App_Glom* DataWidget::get_application()
   return dynamic_cast<App_Glom*>(pWindow);
 }
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 void DataWidget::on_child_layout_item_added(LayoutWidgetBase::enumType item_type)
 {
+  //Tell the parent widget that this widget wants to add an item:
   signal_layout_item_added().emit(item_type);
 }
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
 Gtk::Widget* DataWidget::get_data_child_widget()
 {
@@ -687,92 +748,123 @@ const Gtk::Widget* DataWidget::get_data_child_widget() const
  }
 
 void DataWidget::on_button_choose_date()
-{  
+{
+  Glib::RefPtr<Gnome::Glade::Xml> refXml;
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_choose_date");
-
-    Dialog_ChooseDate* dialog = 0;
-    refXml->get_widget_derived("dialog_choose_date", dialog);
-
-    if(dialog)
-    {
-      dialog->set_transient_for(*get_application());
-      dialog->set_date_chosen(get_value());
-
-      const int response = Glom::Utils::dialog_run_with_help(dialog, "dialog_choose_date");
-      dialog->hide();
-      if(response == Gtk::RESPONSE_OK)
-      {
-        //Get the chosen date
-        const Gnome::Gda::Value value = dialog->get_date_chosen();
-        set_value(value);
-
-        m_signal_edited.emit(value);
-      }
-
-      delete dialog;
-    }
+    refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_date");
   }
   catch(const Gnome::Glade::XmlError& ex)
   {
     std::cerr << ex.what() << std::endl;
+    return;
   }
- }
+#else
+  std::auto_ptr<Gnome::Glade::XmlError> error;
+  refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_date", "", error);
+  if(error.get())
+  {
+    std::cerr << error->what() << std::endl;
+    return;
+  }
+#endif
 
- bool DataWidget::offer_related_record_id_find(Gnome::Gda::Value& chosen_id)
- {
+  Dialog_ChooseDate* dialog = 0;
+  refXml->get_widget_derived("dialog_choose_date", dialog);
+
+  if(dialog)
+  {
+    dialog->set_transient_for(*get_application());
+    dialog->set_date_chosen(get_value());
+
+    const int response = Glom::Utils::dialog_run_with_help(dialog, "dialog_choose_date");
+    dialog->hide();
+    if(response == Gtk::RESPONSE_OK)
+    {
+      //Get the chosen date
+      const Gnome::Gda::Value value = dialog->get_date_chosen();
+      set_value(value);
+
+      m_signal_edited.emit(value);
+    }
+
+    delete dialog;
+  }
+}
+
+void DataWidget::on_self_style_changed(const Glib::RefPtr<Gtk::Style>& style)
+{
+  sharedptr<LayoutItem_Field> layoutField = sharedptr<LayoutItem_Field>::cast_dynamic(get_layout_item());
+  set_child_size_by_field(layoutField);
+}
+
+bool DataWidget::offer_related_record_id_find(Gnome::Gda::Value& chosen_id)
+{
   bool result = false;
 
   //Initialize output variable:
   chosen_id = Gnome::Gda::Value();
 
+  Glib::RefPtr<Gnome::Glade::Xml> refXml;
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_find_id");
-
-    Dialog_ChooseID* dialog = 0;
-    refXml->get_widget_derived("dialog_find_id", dialog);
-
-    if(dialog)
-    {
-      //dialog->set_document(get_document(), table_name, field);
-      dialog->set_transient_for(*get_application());
-      add_view(dialog);
-
-      //Discover the related table, in the relationship that uses this ID field:
-      Glib::ustring related_table_name;
-      sharedptr<LayoutItem_Field> layoutField = sharedptr<LayoutItem_Field>::cast_dynamic(get_layout_item());
-      if(layoutField)
-      {
-        sharedptr<Relationship> relationship = get_document()->get_field_used_in_relationship_to_one(m_table_name, layoutField->get_name());
-        if(relationship)
-          related_table_name = relationship->get_to_table();
-      }
-      else
-        g_warning("get_layout_item() was not a LayoutItem_Field");
-
-      dialog->init_db_details(related_table_name);
-
-
-      int response = dialog->run();
-      dialog->hide();
-      if(response == Gtk::RESPONSE_OK)
-      {
-        //Get the chosen field:
-        result = dialog->get_id_chosen(chosen_id);
-      }
-
-      remove_view(dialog);
-      delete dialog;
-    }
+    refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom.glade"), "dialog_find_id");
   }
   catch(const Gnome::Glade::XmlError& ex)
   {
     std::cerr << ex.what() << std::endl;
+    return result;
+  }
+#else
+  std::auto_ptr<Gnome::Glade::XmlError> error;
+  refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom.glade"), "dialog_find_id", "", error);
+  if(error.get())
+  {
+    std::cerr << error->what() << std::endl;
+    return result;
+  }
+#endif
+
+  Dialog_ChooseID* dialog = 0;
+  refXml->get_widget_derived("dialog_find_id", dialog);
+
+  if(dialog)
+  {
+    //dialog->set_document(get_document(), table_name, field);
+    dialog->set_transient_for(*get_application());
+    add_view(dialog);
+
+    //Discover the related table, in the relationship that uses this ID field:
+    Glib::ustring related_table_name;
+    sharedptr<LayoutItem_Field> layoutField = sharedptr<LayoutItem_Field>::cast_dynamic(get_layout_item());
+    if(layoutField)
+    {
+      sharedptr<Relationship> relationship = get_document()->get_field_used_in_relationship_to_one(m_table_name, layoutField->get_name());
+      if(relationship)
+        related_table_name = relationship->get_to_table();
+    }
+    else
+      g_warning("get_layout_item() was not a LayoutItem_Field");
+
+    dialog->init_db_details(related_table_name);
+
+
+    int response = dialog->run();
+    dialog->hide();
+    if(response == Gtk::RESPONSE_OK)
+    {
+      //Get the chosen field:
+      result = dialog->get_id_chosen(chosen_id);
+    }
+
+    remove_view(dialog);
+    delete dialog;
   }
 
   return result;
 }
 
+
 } //namespace Glom
