@@ -19,10 +19,10 @@
  */
 
 #ifndef GLOM_UTILITY_WIDGETS_NOTEBOOK_GLOM_H
-#define GLOM_UTILITY_WIDGETS_BUTTON_GLOM_H
+#define GLOM_UTILITY_WIDGETS_NOTEBOOK_GLOM_H
 
 #include <gtkmm.h>
-#include "layoutwidgetbase.h"
+#include "layoutwidgetmenu.h"
 #include <glom/libglom/data_structure/layout/layoutitem_notebook.h>
 #include <libglademm.h>
 
@@ -33,13 +33,15 @@ class App_Glom;
 
 class NotebookGlom
 : public Gtk::Notebook,
-  public LayoutWidgetBase
+  public LayoutWidgetMenu
 {
 public:
   explicit NotebookGlom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
   explicit NotebookGlom();
   virtual ~NotebookGlom();
 
+  void delete_from_layout();  
+  
 protected:
   void init();
 
@@ -48,5 +50,5 @@ protected:
 
 } //namespace Glom
 
-#endif //GLOM_UTILITY_WIDGETS_BUTTON_GLOM_H
+#endif //GLOM_UTILITY_WIDGETS_NOTEBOOK_GLOM_H
 
